@@ -1,6 +1,4 @@
 package Rubric;
-use strict;
-use warnings;
 
 =head1 NAME
 
@@ -8,25 +6,31 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.13_02
+version 0.01
 
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric.pm 18601 2006-02-10T12:04:21.459296Z rjbs  $
+ $Id: Rubric.pm,v 1.2 2004/12/16 14:08:18 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.13_02';
+our $VERSION = '0.01';
+
+warn "Rubric.pm isn't meant to be used.";
+exit 1;
 
 =head1 DESCRIPTION
 
 This module is currently just a placeholder and a container for documentation.
-You don't want to actually C<use Rubric>, even if you want to use Rubric.
+You don't want to actually C<use Rubric>, even if you use Rubric.
 
 Rubric is a note-keeping system that also serves as a bookmark manager.  Users
 store entries, which are small (or large) notes with a set of categorizing
 "tags."  Entries may also refer to URIs.
 
 Rubric was inspired by the excellent L<http://del.icio.us/> service and the
-Notational Velocity note-taking software for Mac OS.
+Notational Velocity note-taking software for Mac OS.  At present, it is
+primarily a del.icio.us clone, but its note-taking features will continue to
+grow.  (It can also be used as a blog, which will become easier in future
+iterations.)
 
 =head1 WARNING
 
@@ -34,8 +38,8 @@ This is young software, likely to have bugs and likely to change in strange
 ways.  I will try to keep the documented API stable, but not if it makes
 writing Rubric too inconvenient.
 
-Basically, just take note that this software works, but it's still very much
-under construction.
+Basically, just take note that this software is still version 0.0x; it works,
+but it's still very much under construction.
 
 =head1 INSTALLING AND UPGRADING
 
@@ -51,11 +55,6 @@ L<http://rjbs.manxome.org/rubric/docs/todo>.
 
 Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
-=head1 THANKS
-
-...to a lot of people whom I will try to name, in time.  Among these helpful
-people are Ian Langworth, Shawn Sorichetti, John Cappiello, and Dave O'Neill.
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
@@ -63,34 +62,11 @@ through the web interface at L<http://rt.cpan.org>. I will be notified, and
 then you'll automatically be notified of progress on your bug as I make
 changes.
 
-You can also find some useful people on the #rubric channel on Freenode IRC or
-on the mailing list: L<http://www.listbox.com/subscribe/?listname=rubric>
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<http://del.icio.us/>
-
-one of my original inspirations
-
-=item * L<http://pubweb.northwestern.edu/~zps869/nv.html>
-
-Notational Velocity, another of my inspirations
-
-=item * L<http://unalog.com/>
-
-a social bookmarks system, written in Python
-
-=item * L<http://www.tecknik.net/scuttle/>
-
-a social bookmarks system, written in PHP
-
-=back
+You can also find some support on the #rubric channel on Freenode IRC.
 
 =head1 COPYRIGHT
 
-Copyright 2004-2006 Ricardo SIGNES.  This program is free software;  you can
+Copyright 2004 Ricardo SIGNES.  This program is free software;  you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
